@@ -4,8 +4,8 @@
 
 ;; Author: James Ferguson <(concat "wjcferguson" at-sign "gmail.com")>
 ;; URL: https://github.com/WJCFerguson/emacs-faff-theme
-;; Package-Version: 3.9.1
-;; Package-Revision: 216b52467e2f
+;; Package-Version: 20251120.1400
+;; Package-Revision: e8b6b4b5669f
 ;; Keywords: color theme
 
 ;; This file is not part of GNU Emacs.
@@ -57,7 +57,6 @@
  '(ansi-color-magenta ((t (:background "magenta4" :foreground "magenta4"))))
  '(ansi-color-slow-blink ((t (:box (1 . -1)))))
  '(ansi-color-yellow ((t (:background "yellow4" :foreground "yellow4"))))
- '(ansi-color-faint ((t (:foreground "gray50"))))
  '(bookmark-face ((t (:background "cornsilk3" :foreground "DarkOrange1"))))
  '(breakpoint-disabled ((t (:foreground "grey40"))))
  '(eglot-highlight-symbol-face ((t (:background "cornsilk2" :inherit bold))))
@@ -67,7 +66,7 @@
  '(eshell-ls-executable ((t (:foreground "DarkGreen" :weight bold))))
  '(eshell-ls-product ((t (:foreground "OrangeRed4"))))
  '(eshell-ls-special ((t (:foreground "Magenta4" :weight bold))))
- '(eshell-prompt ((t (:background "#ddd8bd"))))
+ '(eshell-prompt ((t (:background "cornsilk2" :weight bold))))
  '(match ((t (:background "yellow2"))))
  '(cursor ((t (:background "red3"))))
  '(variable-pitch ((t (:family "Sans Serif"))))
@@ -238,13 +237,8 @@
  '(symbol-overlay-face-4 ((t (:background "orchid1" :foreground "black"))))
  '(symbol-overlay-face-5 ((t (:background "red1" :foreground "black"))))
  '(tab-bar ((t (:background "#aca895" :height 0.9))))
- '(tab-bar-tab-inactive ((t (:inherit (variable-pitch tab-bar)))))
+ '(tab-bar-tab-inactive ((t (:inherit (variable-pitch tab-tar)))))
  '(tab-bar-tab ((t (:inherit (tab-bar-tab-inactive) :background "cornsilk3"))))
- '(tab-line ((t (:background "#aca895" :height 0.9))))
- '(tab-line-tab ((t (:inherit (variable-pitch tab-line)))))
- '(tab-line-tab-inactive ((t (:inherit (variable-pitch tab-line)))))
- '(tab-line-tab-current ((t (:inherit (tab-line-tab-inactive) :background "cornsilk3"))))
- '(tab-line-highlight ((t (:inherit (tab-line bold)))))
  '(term-color-green ((t (:background "green4" :foreground "green4"))))
  '(term-color-cyan ((t (:background "cyan4" :foreground "cyan4"))))
  '(term-color-magenta ((t (:background "magenta4" :foreground "magenta4"))))
